@@ -1,22 +1,20 @@
-#===============================================================================
+# ===============================================================================
 # Created:        20 Oct 2021
 # @author:        Jesse Wilson (Anaplan Asia Pte Ltd)
 # Description:    Class to contain Anaplan Auth Token details required for all API calls
 # Input:          Auth token value and expiry
 # Output:         None
-#===============================================================================
+# ===============================================================================
+from dataclasses import dataclass
 
+
+@dataclass
 class AuthToken(object):
-    '''
-    classdocs
-    '''
+    """AuthToken object stores Anaplan auth header and expiry time"""
+    token_value: str
+    token_expiry: str
 
-    def __init__(self, token_value, token_expiry):
-        '''
-        :param token_value: Auth token value
-        :param token_expiry: Epoch time when token expires
-        '''
-        
+    def __init__(self, token_value: str, token_expiry: str):
         self.token_value = token_value
         self.token_expiry = token_expiry
 
@@ -30,4 +28,4 @@ class AuthToken(object):
         return self.token_expiry
 
     def set_token_expiry(self, token_expiry):
-        self.token_expiry = token_expiry
\ No newline at end of file
+        self.token_expiry = token_expiry
